@@ -279,6 +279,52 @@ def get_default_allele(gene, assembly='GRCh37'):
     allele = df[df.Gene == gene][f'{assembly}Default'].values[0]
     return allele
 
+def get_exon_ends(gene, assembly='GRCh37'):
+    """
+    Get exon ends for specified gene.
+
+    Parameters
+    ----------
+    gene : str
+        Gene name.
+    assembly : {'GRCh37', 'GRCh38'}, default: 'GRCh37'
+        Reference genome assembly.
+
+    Returns
+    -------
+    list
+        List of end positions.
+    """
+    if gene not in list_genes(mode='all'):
+        raise GeneNotFoundError(gene)
+    df = load_gene_table()
+    df = df[df.Gene == gene]
+    s = df[f'{assembly}ExonEnds'].values[0]
+    return [int(x) for x in s.strip(',').split(',')]
+
+def get_exon_starts(gene, assembly='GRCh37'):
+    """
+    Get exon starts for specified gene.
+
+    Parameters
+    ----------
+    gene : str
+        Gene name.
+    assembly : {'GRCh37', 'GRCh38'}, default: 'GRCh37'
+        Reference genome assembly.
+
+    Returns
+    -------
+    list
+        List of start positions.
+    """
+    if gene not in list_genes(mode='all'):
+        raise GeneNotFoundError(gene)
+    df = load_gene_table()
+    df = df[df.Gene == gene]
+    s = df[f'{assembly}ExonStarts'].values[0]
+    return [int(x) for x in s.strip(',').split(',')]
+
 def get_function(gene, allele):
     """
     Get matched function from the allele table.
@@ -492,6 +538,28 @@ def get_score(gene, allele):
 
     return df.ActivityScore.values[0]
 
+def get_strand(gene):
+    """
+    Get DNA strand ('+' or '-') for specified gene.
+
+    Parameters
+    ----------
+    gene : str
+        Gene name.
+
+    Returns
+    -------
+    str
+        '+' or '-'.
+    """
+    if not is_target_gene(gene):
+        raise NotTargetGeneError(gene)
+
+    df = load_gene_table()
+    df = df[df.Gene == gene]
+
+    return df['Strand'].values[0]
+
 def get_variant_impact(variant):
     """
     Get variant impact from the variant table.
@@ -1029,6 +1097,8 @@ def predict_score(gene, allele):
     Examples
     --------
 
+    Here are some examples for the CYP2D6 gene:
+
     >>> import pypgx
     >>> pypgx.predict_score('CYP2D6', '*1')            # Allele with normal function
     1.0
@@ -1048,7 +1118,21 @@ def predict_score(gene, allele):
     0.25
     >>> pypgx.predict_score('CYP2D6', '*1x2+*4x2+*10') # Complex event
     2.25
-    >>> pypgx.predict_score('CYP2B6', '*1')            # CYP2B6 does not have activity score
+
+    We can also predict phenotypes for the DPYD gene:
+
+    >>> pypgx.predict_phenotype('DPYD', 'Reference', 'Reference')
+    'Normal Metabolizer'
+    >>> pypgx.predict_phenotype('DPYD', 'Reference', 'c.1905+1G>A (*2A)')
+    'Intermediate Metabolizer'
+    >>> pypgx.predict_phenotype('DPYD', 'c.295_298delTCAT (*7)', 'c.703C>T (*8)')
+    'Poor Metabolizer'
+
+    All of the CYP2B6 alleles will return ``NaN`` because it does not have activity score:
+
+    >>> pypgx.predict_score('CYP2B6', '*1')
+    nan
+    >>> pypgx.predict_score('CYP2B6', '*2')
     nan
     """
     if not is_target_gene(gene):
@@ -1057,19 +1141,25 @@ def predict_score(gene, allele):
     if not has_score(gene):
         return np.nan
 
+    df = load_gene_table()
+    df = df[df.Gene == gene]
+    is_sv_gene = df.SV.values[0]
+
     df = load_allele_table()
     df = df[df.Gene == gene]
 
-    def parsecnv(x):
-        if 'x' in x:
-            l = x.split('x')
-            base = l[0]
-            times = int(l[1])
-            return get_score(gene, base) * times
-        else:
-            return get_score(gene, x)
-
-    return sum([parsecnv(x) for x in allele.split('+')])
+    if is_sv_gene:
+        def parsecnv(x):
+            if 'x' in x:
+                l = x.split('x')
+                base = l[0]
+                times = int(l[1])
+                return get_score(gene, base) * times
+            else:
+                return get_score(gene, x)
+        return sum([parsecnv(x) for x in allele.split('+')])
+    else:
+        return get_score(gene, allele)
 
 def sort_alleles(
     alleles, by='priority', gene=None, assembly='GRCh37'
