@@ -12,7 +12,8 @@ from .. import sdk
 from . import utils, plot, genotype, core
 
 def run_chip_pipeline(
-    gene, output, variants, panel=None, impute=False, force=False
+    gene, output, variants, panel=None, assembly='GRCh37', impute=False,
+    force=False
 ):
     """
     Run PyPGx's genotyping pipeline for chip data.
@@ -25,6 +26,8 @@ def run_chip_pipeline(
         Output directory.
     variants : str
         VCF file (zipped or unzipped).
+    assembly : {'GRCh37', 'GRCh38'}, default: 'GRCh37'
+        Reference genome assembly.
     impute : bool, default: False
         If True, perform imputation of missing genotypes.
     force : bool, default : False
@@ -38,11 +41,14 @@ def run_chip_pipeline(
 
     os.mkdir(output)
 
-    imported_variants = utils.import_variants(gene, variants, platform='Chip')
+    imported_variants = utils.import_variants(gene, variants,
+        assembly=assembly, platform='Chip')
     imported_variants.to_file(f'{output}/imported-variants.zip')
-    phased_variants = utils.estimate_phase_beagle(imported_variants, panel=panel, impute=impute)
+    phased_variants = utils.estimate_phase_beagle(imported_variants,
+        panel=panel, impute=impute)
     phased_variants.to_file(f'{output}/phased-variants.zip')
-    consolidated_variants = utils.create_consolidated_vcf(imported_variants, phased_variants)
+    consolidated_variants = utils.create_consolidated_vcf(
+        imported_variants, phased_variants)
     consolidated_variants.to_file(f'{output}/consolidated-variants.zip')
     alleles = utils.predict_alleles(consolidated_variants)
     alleles.to_file(f'{output}/alleles.zip')
@@ -57,7 +63,7 @@ def run_chip_pipeline(
 
 def run_ngs_pipeline(
     gene, output, variants=None, depth_of_coverage=None,
-    control_statistics=None, platform='WGS', panel=None,
+    control_statistics=None, platform='WGS', assembly='GRCh37', panel=None,
     force=False, samples=None, do_not_plot_copy_number=False,
     do_not_plot_allele_fraction=False
 ):
@@ -84,6 +90,8 @@ def run_ngs_pipeline(
         Archive file or object with the semantic type SampleTable[Statistics].
     platform : {'WGS', 'Targeted'}, default: 'WGS'
         Genotyping platform.
+    assembly : {'GRCh37', 'GRCh38'}, default: 'GRCh37'
+        Reference genome assembly.
     panel : str, optional
         VCF file corresponding to a reference haplotype panel (zipped or
         unzipped). By default, the 1KGP panel is used.
@@ -99,30 +107,51 @@ def run_ngs_pipeline(
     if not core.is_target_gene(gene):
         raise core.NotTargetGeneError(gene)
 
-    if os.path.exists(output) and force:
-        shutil.rmtree(output)
-
-    os.mkdir(output)
-
     gene_table = core.load_gene_table()
+    small_var = gene_table[gene_table.Gene == gene].Variants.values[0]
+    large_var = gene_table[gene_table.Gene == gene].SV.values[0]
 
-    alleles = None
-    cnv_calls = None
-
-    if not gene_table[gene_table.Gene == gene].Variants.values[0] and variants is not None:
+    if not small_var and variants is not None:
         message = (
-            'The user provided a VCF file even though the target gene does '
+            'User provided a VCF file even though the target gene does '
             'not have any star alleles defined by SNVs/indels. PyPGx will '
             'ignore it.'
         )
         warnings.warn(message)
 
-    if gene_table[gene_table.Gene == gene].Variants.values[0] and variants is not None:
-        imported_variants = utils.import_variants(gene, variants, platform=platform)
+    if not large_var and depth_of_coverage is not None:
+        message = (
+            'User provided CovFrame[DepthOfCoverage] even though the '
+            'target gene does not have any star alleles defined by SVs. '
+            'PyPGx will ignore it.'
+        )
+        warnings.warn(message)
+
+    if not large_var and control_statistics is not None:
+        message = (
+            'User provided SampleTable[Statistics] even though the '
+            'target gene does not have any star alleles defined by SVs. '
+            'PyPGx will ignore it.'
+        )
+        warnings.warn(message)
+
+    alleles = None
+    cnv_calls = None
+
+    if os.path.exists(output) and force:
+        shutil.rmtree(output)
+
+    os.mkdir(output)
+
+    if small_var and variants is not None:
+        imported_variants = utils.import_variants(gene, variants,
+            assembly=assembly, platform=platform)
         imported_variants.to_file(f'{output}/imported-variants.zip')
-        phased_variants = utils.estimate_phase_beagle(imported_variants, panel=panel)
+        phased_variants = utils.estimate_phase_beagle(
+            imported_variants, panel=panel)
         phased_variants.to_file(f'{output}/phased-variants.zip')
-        consolidated_variants = utils.create_consolidated_vcf(imported_variants, phased_variants)
+        consolidated_variants = utils.create_consolidated_vcf(
+            imported_variants, phased_variants)
         consolidated_variants.to_file(f'{output}/consolidated-variants.zip')
         alleles = utils.predict_alleles(consolidated_variants)
         alleles.to_file(f'{output}/alleles.zip')
@@ -132,19 +161,13 @@ def run_ngs_pipeline(
                 imported_variants, path=f'{output}/allele-fraction-profile'
             )
 
-    if not gene_table[gene_table.Gene == gene].SV.values[0] and depth_of_coverage is not None:
-        message = (
-            'The user provided CovFrame[DepthOfCoverage] even though the '
-            'target gene does not have any star alleles defined by SVs. '
-            'PyPGx will ignore it.'
-        )
-        warnings.warn(message)
-
-    if gene_table[gene_table.Gene == gene].SV.values[0] and depth_of_coverage is not None:
+    if large_var and depth_of_coverage is not None:
         if isinstance(depth_of_coverage, str):
             depth_of_coverage = sdk.Archive.from_file(depth_of_coverage)
 
-        depth_of_coverage.check('CovFrame[DepthOfCoverage]')
+        depth_of_coverage.check_type('CovFrame[DepthOfCoverage]')
+        depth_of_coverage.check_metadata('Platform', platform)
+        depth_of_coverage.check_metadata('Assembly', assembly)
 
         if control_statistics is None:
             raise ValueError('SV detection requires SampleTable[Statistcs]')
@@ -152,10 +175,9 @@ def run_ngs_pipeline(
         if isinstance(control_statistics, str):
             control_statistics = sdk.Archive.from_file(control_statistics)
 
-        control_statistics.check('SampleTable[Statistics]')
-
-        if depth_of_coverage.metadata['Platform'] != control_statistics.metadata['Platform']:
-            raise ValueError('Different platforms detected')
+        control_statistics.check_type('SampleTable[Statistics]')
+        control_statistics.check_metadata('Platform', platform)
+        control_statistics.check_metadata('Assembly', assembly)
 
         read_depth = utils.import_read_depth(gene, depth_of_coverage)
         read_depth.to_file(f'{output}/read-depth.zip')
@@ -166,8 +188,7 @@ def run_ngs_pipeline(
         if not do_not_plot_copy_number:
             os.mkdir(f'{output}/copy-number-profile')
             plot.plot_bam_copy_number(
-                copy_number, path=f'{output}/copy-number-profile', ymin=0,
-                ymax=6
+                copy_number, path=f'{output}/copy-number-profile'
             )
 
     genotypes = genotype.call_genotypes(alleles=alleles, cnv_calls=cnv_calls)
