@@ -31,17 +31,9 @@ def create_parser(subparsers):
         metavar='read-depth',
         help='Archive file with the semantic type CovFrame[ReadDepth].'
     )
-    parser.add_argument(
-        '--assembly',
-        metavar='TEXT',
-        default='GRCh37',
-        choices=['GRCh37', 'GRCh38'],
-        help="Reference genome assembly (default: 'GRCh37') (choices: \n"
-             "'GRCh37', 'GRCh38')."
-    )
 
 def main(args):
     archive = utils.import_read_depth(
-        args.gene, args.depth_of_coverage, assembly=args.assembly,
+        args.gene, args.depth_of_coverage
     )
     archive.to_file(args.read_depth)
